FlowBot

Struct FlowBot 

pub struct FlowBot { /* private fields */ }

Implementations

Source

impl FlowBot

pub async fn run(&self) -> Result<(), FlowError>

Run the bot. This will connect to the server and start processing events. This method will never return unless an error occurs or reconnection attempts are exhausted.